@@ -26,7 +26,7 @@
 #include <tqstring.h>
 #include <list>
 
-#ifdef __TDE_HAVE_TDEHWLIB
+#ifdef HAVE_TDEHWLIB
 class TDEHardwareDevices;
 #else
 #define TDEHardwareDevices void
